#========================================================================================
# package      DE_EPAGES::Amazon::API::Constants
# state        public
#----------------------------------------------------------------------------------------
# description  This is the place for common Amazon values and constants.
#========================================================================================
package DE_EPAGES::Amazon::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw(
  %AMAZON_ITEM_CONDITIONS
  %AMAZON_ONLINESTATUS
  %AMAZON_PROCESSINGSTATUS
  %AMAZON_FEEDS
  %AMAZON_PENDING_FEEDS
  %SOAP_ACTION_KEYS
  MERCHANT_SOAP_URI
  ItemConditionValues
  %MAP_LOCALE
  NUM_MAX_DOCUM_ACK
  MIN_DELIVERY_LATENCY
  MAX_DELIVERY_LATENCY
);

our %AMAZON_ITEM_CONDITIONS = (
    'New'                   => 0,
    'Refurbished'           => 1,
    'UsedLikeNew'           => 2,
    'UsedVeryGood'          => 3,
    'UsedGood'              => 4,
    'UsedAcceptable'        => 5,
    'CollectibleLikeNew'    => 6,
    'CollectibleVeryGood'   => 7,
    'CollectibleGood'       => 8,
    'CollectibleAcceptable' => 9,
);

our %AMAZON_ONLINESTATUS = (
    'OFFER_OFFLINE'    => 0,   # preparing, not online
    'OFFER_FAILED'     => 1,   # upload error
    'OFFER_PROCESSING' => 2,   # pending, not online yet (set to OFFER_ONLINE by scheduler)
    'OFFER_ONLINE'     => 4,   # online
    'OFFER_HIDDEN'     => 8,   # deactivated, still online (set to OFFER_OFFLINE by scheduler)
);

our %AMAZON_PROCESSINGSTATUS = (
    '_IN_PROGRESS_' => 0,
    '_DONE_'        => 1,
);

our %AMAZON_FEEDS = (
    '_POST_PRODUCT_DATA_'                => 0,
    '_POST_PRODUCT_RELATIONSHIP_DATA_'   => 1,
    '_POST_PRODUCT_OVERRIDES_DATA_'      => 2,
    '_POST_PRODUCT_IMAGE_DATA_'          => 3,
    '_POST_PRODUCT_PRICING_DATA_'        => 4,
    '_POST_INVENTORY_AVAILABILITY_DATA_' => 5,
    '_POST_ORDER_ACKNOWLEDGEMENT_DATA_'  => 6,
    '_POST_ORDER_FULFILLMENT_DATA_'      => 7,
    '_POST_PAYMENT_ADJUSTMENT_DATA_'     => 8,
    '_POST_STORE_DATA_'                  => 9,
    '_POST_OFFER_ONLY_DATA_'             => 10,
);

our %AMAZON_PENDING_FEEDS = (
    'orders'   => '_GET_ORDERS_DATA_'
);

use constant MERCHANT_SOAP_URI => 'http://www.amazon.com/merchants/merchant-interface/MerchantInterface';

our %SOAP_ACTION_KEYS = (    # STATIC URL Elements defined by Amazon WSDL
    getAllPendingDocumentInfo =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7TGphdmEvbGFuZy9TdHJpbmc7KVtMd2FzcGNTZXJ2ZXIvQW16SVNBL01lcmNoYW50RG9jdW1lbnRJbmZvOw==",
    postDocument =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7TGphdmEvbGFuZy9TdHJpbmc7TG9yZy9pZG9veC93YXNwL3R5cGVzL1JlcXVlc3RNZXNzYWdlQXR0YWNobWVudDspTHdhc3BjU2VydmVyL0FteklTQS9Eb2N1bWVudFN1Ym1pc3Npb25SZXNwb25zZTs=",
    getDocument =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7TGphdmEvbGFuZy9TdHJpbmc7TG9yZy9pZG9veC93YXNwL3R5cGVzL1Jlc3BvbnNlTWVzc2FnZUF0dGFjaG1lbnQ7KUxqYXZhL2xhbmcvU3RyaW5nOw==",
    postDocumentDownloadAck =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7W0xqYXZhL2xhbmcvU3RyaW5nOylbTHdhc3BjU2VydmVyL0FteklTQS9Eb2N1bWVudERvd25sb2FkQWNrU3RhdHVzOw==",
    getDocumentProcessingStatus =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7SilMd2FzcGNTZXJ2ZXIvQW16SVNBL0RvY3VtZW50UHJvY2Vzc2luZ0luZm87",
    getLastNDocumentInfo =>
"KEx3YXNwY1NlcnZlci9BbXpJU0EvTWVyY2hhbnQ7TGphdmEvbGFuZy9TdHJpbmc7SSlbTHdhc3BjU2VydmVyL0FteklTQS9NZXJjaGFudERvY3VtZW50SW5mbzs=",
);

our %MAP_LOCALE = (
    'fr' => 'fr_FR',
    'de' => 'de_DE',
    'it' => 'it_IT',
    'es' => 'es_ES',
    'uk' => 'en_GB',
);

use constant NUM_MAX_DOCUM_ACK => 50;

# allowed range in days for the delivery latency
use constant MIN_DELIVERY_LATENCY => 1;
use constant MAX_DELIVERY_LATENCY => 30;

#========================================================================================
# function     ItemConditionValues
# state        public
#----------------------------------------------------------------------------------------
# syntax       %hSplitCond = DE_EPAGES::Amazon::API::Constants->ItemConditionValues("UsedLikeNew");
#----------------------------------------------------------------------------------------
# description  Splits the condition value into a hash
#----------------------------------------------------------------------------------------
# input        $Condition  | combined condition string | string
# return       %hSplitCond | split condition values    | hash
#               used keys are:
#               <ul>
#                 <li>CompleteString - input as-is
#                 <li>MainCondition  - main condition, e.g. "Used"
#                 <li>SubCondition   - subcondition, e.g. "LikeNew"
#               </ul>
#========================================================================================
sub ItemConditionValues ($) {
    my ($ID) = @_;
    my $hRet = {};
    foreach my $key ( keys %AMAZON_ITEM_CONDITIONS ) {
        my $value = $AMAZON_ITEM_CONDITIONS{$key};
        if (   $value == $ID
            && $key =~ /^(New|Used|Collectible|Refurbished)(.*)/x )
        {
            $hRet = {
                'CompleteString' => $key,
                'MainCondition'  => $1,
                'SubCondition'   => ( $2 ? $2 : $1 ),
            };
            return $hRet;
        }
    }
    return $hRet;
}

1;
