package DE_EPAGES::AppStore::UI::Shop;
use base DE_EPAGES::Presentation::UI::Object;

use DE_EPAGES::AppStore::API::Object::DeveloperAppsClient;
use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use DE_EPAGES::Core::API::Url qw ( StringIsURL );
use DE_EPAGES::Shop::API::Constants qw( UNITY_STOREFRONT_APP_NAME );
use List::Util qw (reduce);

use strict;

use constant APPLICATION_SCOPES => qw (
    carts_read
    carts_write
    coupons_read
    coupons_write
    customers_read
    customers_write
    legal_read
    legal_write
    newsletters_read
    newsletters_write
    orders_read
    orders_write
    products_read
    products_read_batch
    products_write
    scripttags_read
    scripttags_write
);


sub ViewDeveloperApps {
    my $self      = shift;
    my ($Servlet) = @_;
    my $Shop      = $Servlet->object;

    my $AppsClient = $self->_createDeveloperAppsClient($Shop);
    my $aAllApps      = $AppsClient->listApps( $Shop->guid )->{'content'};

    # test if we have an UNITY Shop and filter out "Unity Storefront" app because this is an internal App
    # communication UNITY SF->REST API is here authenticated
    my $aApps = $aAllApps;

    if($Shop->isUnity()){
        $aApps=[];
        foreach my $App (@$aAllApps){
            push @$aApps, $App unless $App->{'name'} eq UNITY_STOREFRONT_APP_NAME;
        }
    }

    $Servlet->vars( "DeveloperApps", $aApps );

    return;
}

sub SaveDeveloperApp {
    my $self = shift;
    my ($Servlet) = @_;

    my $Shop = $Servlet->object;
    my $hInputValues = $Servlet->form->form( $Shop, 'DeveloperApp' );

    my $aScopes = $self->_getSelectedScopes($hInputValues);

    my $ScopesCount = scalar (@$aScopes);
    if ($ScopesCount == 0) {
            $Servlet->form->addFormError( {
                Reason => 'EMPTY_SCOPES',
                Name   => 'Scopes',
                Form   => 'DeveloperApp'
            } );
    }

    if ($self->_IsInvalidUrl($hInputValues)) {
        $Servlet->form->addFormError( {
                Reason => 'INVALID_URL',
                Name   => 'CallbackUrl',
                Form   => 'DeveloperApp'
            }
        );
    }

    $Servlet->form->executeFormError();

    my $AppsClient = $self->_createDeveloperAppsClient($Shop);
    my $CreatedApp = $AppsClient->createApp( $hInputValues->{'AppName'}, $hInputValues->{'CallbackUrl'}, $aScopes );

    $Servlet->vars( "DeveloperApp", $CreatedApp );
    return;
}

sub _getSelectedScopes {
    my $self = shift;
    my ($hFormEntries) = @_;

    my $aScopes = [];
    foreach my $Scope (APPLICATION_SCOPES) {
        push(@$aScopes, $Scope) if ($hFormEntries->{$Scope});
    }

    return $aScopes;
}

sub _IsInvalidUrl {
    my $self = shift;
    my ($hFormEntries) = @_;

    if ( isValid($hFormEntries->{'CallbackUrl'}) ) {
        return 1 unless ( StringIsURL($hFormEntries->{'CallbackUrl'}) );
    }

    return 0;
}

sub DeleteDeveloperApp {
    my $self      = shift;
    my ($Servlet) = @_;
    my $Shop      = $Servlet->object;

    my $hValues    = $Servlet->form->form($Shop, 'DeveloperApps');
    my $AppsClient = $self->_createDeveloperAppsClient($Shop);

    # delete only if accepted if confirmation is used
    if ($Servlet->user->get('DeleteConfirmation') and not $Servlet->params('ACCEPT')) {
        $Servlet->vars('DeleteObjects', [ map { $AppsClient->getApp($_->{'DeveloperAppID'}) } @{$hValues->{DeveloperAppIDs}}]);
        $Servlet->vars('DELETE',1);
        return;
    } else {
        # else reset delete
        $Servlet->vars('DELETE',0);
    }
    foreach my $DeveloperApp ( @{$hValues->{DeveloperAppIDs}} ) {
        $AppsClient->deleteApp($DeveloperApp->{DeveloperAppID});
    }
    return;
}

sub _getDeveloperApp {
    my $self = shift;
    my ( $Servlet, $appID ) = @_;
    my $Shop      = $Servlet->object;

    my $AppsClient = $self->_createDeveloperAppsClient($Shop);
    my $SelectedDeveloperApp = $AppsClient->getApp($appID);
    $Servlet->vars( "DeveloperApp", $SelectedDeveloperApp );
    $Servlet->vars( "Scopes", $self->_getScopeString($SelectedDeveloperApp) );
    return;
}

sub _getScopeString {
    my $self = shift;
    my ( $SelectedDeveloperApp ) = @_;
    my $ScopeArray = $SelectedDeveloperApp->{'scopes'};
    my $ScopeString = reduce { $a . ',' . $b } @{$ScopeArray};
    return $ScopeString;
}

sub ViewDeveloperApp {
    my $self = shift;
    my ($Servlet) = @_;

    my $appID = $Servlet->params("appID");
    my $testAuthorization = $Servlet->params('TestAuthorization');

    if ($appID) {
        # GET the data from epagesj and store it as "DeveloperApp" in the servlet
        $self->_getDeveloperApp( $Servlet, $appID );
        if($testAuthorization){
            $Servlet->vars( "TestAuthorizationResult", $testAuthorization );
        }
    }

    return;
}

sub _createDeveloperAppsClient {
    my $self = shift;
    my ($Shop) = @_;
    return DE_EPAGES::AppStore::API::Object::DeveloperAppsClient->create({'Shop' => $Shop});
}

1;
