#========================================================================================
# package      DE_EPAGES::Content::Hooks::ShopLanguage
# state        public
# description  adds needed data to content objects on change of the shop language
#========================================================================================
package DE_EPAGES::Content::Hooks::ShopLanguage;

use strict;
use DE_EPAGES::Shop::API::ShopLanguage qw ( SetNameForNewLanguage );

#========================================================================================
# function     OnInsertShopLanguage
#----------------------------------------------------------------------------------------
# syntax       OnInsertShopLanguage( $hParams );
#----------------------------------------------------------------------------------------
# description  write the existing name to all categories in the new language
#               (Hook OBJ_InsertShopLanguage)
#----------------------------------------------------------------------------------------
# input        $hParams | hook params, keys:
#               <ul>
#                 <li>Object         - ShopLanguage         - object
#                 <li>ShopLanguageID - object id            - int
#               </ul>
#========================================================================================
sub OnInsertShopLanguage {
    my ($hParams) = @_;

    my $ShopLanguage = $hParams->{'Object'};
    my $Shop = $ShopLanguage->getSite();

    if ($Shop->get('IsUnityRegistered')) {
        my $NewLanguageID = $ShopLanguage->get('LanguageID');
        my $DefaultLanguageID = $Shop->get('LanguageID');

        my $StartPage = $Shop->get('Categories');

        _useNameForNewLanguage($StartPage, $DefaultLanguageID, $NewLanguageID);
    }

    return;
}

sub _useNameForNewLanguage {
    my ($Category, $DefaultLanguageID, $NewLanguageID) = @_;

    SetNameForNewLanguage($Category, $DefaultLanguageID, $NewLanguageID);

    foreach my $SubCategory (@{$Category->children}) {
        _useNameForNewLanguage($SubCategory, $DefaultLanguageID, $NewLanguageID);
    }

    return;

}

1;
