#!/srv/epages/eproot/Perl/bin/perl
use strict;

use Getopt::Long;
use Net::INET6Glue;
use Net::SMTP;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::Core::API::Scheduler qw(GetMailParameters);

sub usage {
    my ($Message) = @_;

    print STDERR "$Message\n\n" if defined $Message;

    print <<END_USAGE;
Usage:
    perl $0 [Options] [Flags]

Options:
    -ini            ini file that contains section -section
    -section        section of ini file
    -SMTPServer     SMTP server name
    -SMTPPort       SMTP server port
    -SMTPLogin      SMTP server login
    -SMTPPassword   SMTP server password
    -from           sender (e-mail address), defaults:
                      1. MailSender from ini file
                      2. SMTPLogin\@SMTPServer
                      3. else: login\@host
    -to             list of recipients separated by [,;], defaults:
                      1. MailRecipient from ini file
                      2. else: From
    -subject        e-mail subject (optional)
    -file           name of file to sent (mandatory)

Flags:
    -help           show the command line options

Example:
    perl $0 -to "ep_appl\@localhost" -subject "Output from SybaseBackup.sh" -file SybaseBackup.log
END_USAGE
    exit 2;
}

sub Main {
    local $| = 1;

    my %Options;
    my @GetOpt = qw(ini=s section=s from=s to=s subject=s file=s debug help
                    SMTPServer=s SMTPPort=s SMTPLogin=s SMTPPassword=s);

    GetOptions(\%Options, @GetOpt) or usage();
    usage() if $Options{help};
    usage('Missing parameter -file') unless $Options{file};
    usage('Parameter -file with nonexisting file: '. $Options{file}) unless -f $Options{file};
    usage('Parameter -file with empty file: '. $Options{file}) unless -s $Options{file};

    my $Params = GetMailParameters(\%Options);
    my $MailHeader = "From: $Params->{from}\nTo: $Params->{to}\nSubject: $Params->{subject}\n";

    open my $FOO, '<', $Params->{file} or die "Can't open $Params->{file}: $!";
    my $Content =  do { local $/ = undef; <$FOO> };
    close $FOO or die "Can't close $Params->{file}: $!";

    my $Smtp = Net::SMTP->new($Params->{SMTPServer}, Port => $Params->{SMTPPort},
                              Debug => $Params->{debug});
    $Smtp->auth($Params->{SMTPLogin}, $Params->{SMTPPassword}) if $Params->{SMTPLogin};
    foreach (split/[,;]/, $Params->{to}) {
        $Smtp->mail($Params->{from}); $Smtp->to($_);
        $Smtp->data(); $Smtp->datasend($MailHeader);
        $Smtp->datasend("\n$Content\n");
        $Smtp->dataend();
    }
    $Smtp->quit;
}

RunScript( 'Sub' => \&Main );

1;
