#!/srv/epages/eproot/Perl/bin/perl
use strict;

use Getopt::Long;
use DE_EPAGES::Core::API::Script qw( RunScript );
use DE_EPAGES::MailType::API::TextMail qw( SendTextMail );
use DE_EPAGES::Core::API::Scheduler qw(GetMailParameters);

sub Main {
    local $| = 1;

    my %Options;
    my @GetOpt = qw(ini=s section=s from=s to=s subject=s file=s descr=s attachment:s help);

    GetOptions(\%Options, @GetOpt) or usage();
    usage() if $Options{help};
    usage('Missing parameter -file') unless $Options{file};
    usage('Parameter -file with nonexisting file: '. $Options{file}) unless -f $Options{file};
    usage('Parameter -file with empty file: '. $Options{file}) unless -s $Options{file};

    SendTextMail( GetMailParameters(\%Options) );
}

sub usage {
    my ($Message) = @_;

    print STDERR "$Message\n\n" if defined $Message;

    print <<END_USAGE;
Usage:
    perl $0 [Options] [Flags]

Options:
    -ini       ini file that contains section -section
    -section   value of key 'MailStore' in section is used for ConnectSite()
                 default: LOOPS
    -from      sender (e-mail address) (default: TBO Reply Address)
    -to        list of recipients separated by [,;] (default: TBO Error Address)
    -subject   e-mail subject (optional)
    -file      name of file to sent (mandatory)
    -descr     additional description (optional)
    -attachment  file is sent as attachment (default: Application/Octet-stream)

Flags:
    -help        show the command line options

Example:
    perl $0 -to "ep_appl\@localhost" -subject "Output from SybaseBackup.sh" -file SybaseBackup.log
END_USAGE
    exit 2;
}

RunScript(
    'Sub' => \&Main
);

1;
