use Test::More tests => 19;

use strict;
use DE_EPAGES::Core::API::Error qw ( ExistsError );
use DE_EPAGES::Core::API::Script qw (RunScript);
use DE_EPAGES::Database::API::Connection qw( ConnectTestSite DisconnectSite );
use DE_EPAGES::MailType::API::Object::SmtpConnection;

RunScript(
    Sub => \&Main
);

sub Main {
    # EPG-18009: Different SMTP server for sending newsletters

    # ------------------------------------------------------------------------
    # missing parameters
    # ------------------------------------------------------------------------

    eval {
        DE_EPAGES::MailType::API::Object::SmtpConnection->new({ 'SMTPPassword' => '123456' });
    };
    ok( ExistsError(), 'Error expected' );
    eval {
        DE_EPAGES::MailType::API::Object::SmtpConnection->new({ 'SMTPServer' => undef, 'SMTPPort' => 25 });
    };
    ok( ExistsError(), 'Error expected' );

    # ------------------------------------------------------------------------
    # custom connection
    # ------------------------------------------------------------------------

    my $hConnection = { 'SMTPServer' => 'fantasymailgate.epages.de',
                        'SMTPPort' => 25,
                        'SMTPLogin' => 'hoppe',
                        'SMTPPassword' => '123456',
    };
    my $smtp = DE_EPAGES::MailType::API::Object::SmtpConnection->new($hConnection);
    ok( $smtp, 'Custom connection - new' );
    is( $smtp->{Server}, $hConnection->{SMTPServer}, 'Custom SMTPServer');
    is( $smtp->{Port}, $hConnection->{SMTPPort}, 'Custom SMTPPort' );
    is( $smtp->{Login}, $hConnection->{SMTPLogin}, 'Custom SMTPLogin' );
    is( $smtp->{Password}, $hConnection->{SMTPPassword}, 'Custom SMTPPassword' );

    $hConnection = { 'SMTPServer' => 'mail',
                     'SMTPPort' => 25,
                     'SMTPLogin' => undef,
                     'SMTPPassword' => undef,
    };
    $smtp = DE_EPAGES::MailType::API::Object::SmtpConnection->new($hConnection);
    ok( $smtp, 'Custom connection - new' );

    $smtp->connection( sub {
        ok( $smtp->existsConnection, 'Custom connection - open' );

        $smtp->send( "test mail body\nsent by $0", {
            'FROM' => 'Test User <test@epages.com>',
            'TO' => [ 'Test User <test@epages.com>' ],
            'SUBJECT' => 'test custom connection',
          });
        ok( 1, 'Custom connection - send' );
    });
    ok( !$smtp->existsConnection, 'Custom connection - close' );

    # ------------------------------------------------------------------------
    # connection from database
    # ------------------------------------------------------------------------

    ConnectTestSite();

    $smtp = DE_EPAGES::MailType::API::Object::SmtpConnection->new;
    ok( $smtp, 'Default connection - new' );
    is( $smtp->{Server}, $hConnection->{SMTPServer}, 'Default SMTPServer');
    is( $smtp->{Port}, $hConnection->{SMTPPort}, 'Default SMTPPort' );
    is( $smtp->{Login}, undef, 'Default SMTPLogin' );
    is( $smtp->{Password}, undef, 'Default SMTPPassword' );

    $smtp->connection( sub {
        ok( $smtp->existsConnection, 'Default connection - open' );
        $smtp->send( "test mail body\nsent by $0", {
            'FROM' => 'Test User <test@epages.com>',
            'TO' => [ 'Test User <test@epages.com>' ],
            'SUBJECT' => 'test default connection',
          });
        ok( 1, 'Default connection - send' );
    });
    ok( !$smtp->existsConnection, 'Default connection - close' );

    DisconnectSite();
}

1;
