#==============================================================================
# package      DE_EPAGES::Ogone::UI::PaymentMethodOgone
# state        private
#==============================================================================
package DE_EPAGES::Ogone::UI::PaymentMethodOgone;
use base DE_EPAGES::Payment::UI::PaymentMethod;

use strict;

use DE_EPAGES::Shop::API::Url qw ( BuildShopUrl );
use DE_EPAGES::Object::API::Factory qw ( Transaction LoadObjectByPath JoinObjectPath );
use DE_EPAGES::Payment::API::Table::ShippingPaymentMap qw ( InsertShippingPaymentMap );
use DE_EPAGES::Core::API::Error qw ( Error ExistsError GetError );
use DE_EPAGES::Payment::API::Shop qw (GetShopPaymentLogos);
use DE_EPAGES::Payment::API::Table::ShopPaymentLogo qw( InsertShopPaymentLogo ExistsShopPaymentLogo );
use DE_EPAGES::Ogone::API::Constants qw (@SPLIT_GATEWAY_METHODS $SPLIT_GATEWAY_METHODS_MAXROWS);

#==============================================================================

sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;
    $Servlet->vars('UpdateURL', BuildShopUrl($Servlet->object->getSite, {'ChangeAction' => 'PaymentCallbackOgone' },
                                                {'UseSSL' => 1, 'UseObjectPath'=> 1}));

    return;
}
sub View {
    my $self = shift;
    my ($Servlet) = @_;

    $self->SUPER::View($Servlet);

    $Servlet->vars('SplitGatewayMethods_MaxRows',$SPLIT_GATEWAY_METHODS_MAXROWS);
    $Servlet->vars('SplitGatewayMethods',\@SPLIT_GATEWAY_METHODS);

    my $Shop = $Servlet->object()->getSite();
    my $PaymentMethods = $Shop->folder('PaymentMethods')->children;

    foreach my $PaymentMethod (@$PaymentMethods) {

        next unless $PaymentMethod->class->alias eq 'PaymentMethodOgone';

        $Servlet->vars('ExistingOgoneMethod_'.$PaymentMethod->get('SplitGatewayMethod'),1);
    }
    return;
}

sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;
    my $PaymentMethod = $Servlet->object;
    my $Form = $Servlet->form;
    my $Shop = $PaymentMethod->getSite();
    my $Folder = $Shop->folder('PaymentMethods');

    # In order to show the sub payment method in the general page of the payment methods
    # we rewrite the Name and Alias before we save the payment method
    my $SplitGatewayMethod = $Form->{'Values'}->{'SplitGatewayMethod'}[0];

    my %hSPLIT_GATEWAY_METHODS = map { ($_->{'ID'}) => $_ } @SPLIT_GATEWAY_METHODS;
    my $nameMethod = $hSPLIT_GATEWAY_METHODS{$SplitGatewayMethod}->{'UIName'} //
                     $hSPLIT_GATEWAY_METHODS{$SplitGatewayMethod}->{'Name'};
    my $aliasMethod = $nameMethod;


    #Check if the payment method for the same payment type already exists, before rewriting
    if ( $Folder->existsChild($aliasMethod)  and
         $PaymentMethod->get('Alias') ne $aliasMethod ) {

            $Form->addFormError({
                'Form'  => 'PaymentMethodOgone',
                'Reason'=> 'OBJECT_EXISTS',
                'Name'  => $SplitGatewayMethod
            });
            $Form->executeFormError;
        }

    # Rewrite the name and the alias of the payment method
    $PaymentMethod->set({'Name' => $nameMethod});
    $PaymentMethod->set({'Alias' => $aliasMethod});

    # some form checks here
    if ( $Form->{'Values'}->{'IsInTestMode'}[0] ) {
        $Form->form($PaymentMethod, 'OgoneTestSettings');
    } else {
        $Form->form($PaymentMethod, 'OgoneSettings');
    }

    #--- standard save
    $self->SUPER::Save($Servlet);

    return;
}
sub NewOgoneMethod {
    my $self = shift;
    my ($Servlet) = @_;

    my $Form = $Servlet->form;
    my $PaymentMethod = $Servlet->object();
    my $Values = $Servlet->form->formValues;

    # Go through the payment methods array and generate a hash with key = ID and value the payment method.
    my %hSPLIT_GATEWAY_METHODS = map { ($_->{'ID'}) => $_ } @SPLIT_GATEWAY_METHODS;


    # We build an array with the selected OgoneMethods in the setting page
    my @aSelectedSplitGatewayMethods = map { /^aOgoneMethod_(.*)/x } grep { /^aOgoneMethod_/x } keys %$Values;

    # We check the selected ogoneMethods
    my $LeftPaymentMethods = _check_newOgoneMethods($Servlet,$PaymentMethod,\@aSelectedSplitGatewayMethods,\%hSPLIT_GATEWAY_METHODS);

    if ( $LeftPaymentMethods > 0 ) {
        splice(@aSelectedSplitGatewayMethods, -1 * $LeftPaymentMethods);
        $Form->addFormError({
                'Form'  => 'PaymentMethodOgone',
                'Reason'=> 'FEATURE_LIMIT_EXCEEDED',
                'Name'  => 'FEATURE_LIMIT_EXCEEDED'
            });
    }



    #We create the diferent selected payment method and add them to an array
    my @newPaymentMethods;
    foreach my $SplitGatewayMethod (@aSelectedSplitGatewayMethods) {
        push(@newPaymentMethods,
             _newOgoneMethod($Servlet,$PaymentMethod,$SplitGatewayMethod,
                             ($hSPLIT_GATEWAY_METHODS{$SplitGatewayMethod}->{'UIName'} //
                             $hSPLIT_GATEWAY_METHODS{$SplitGatewayMethod}->{'Name'}),
                             $hSPLIT_GATEWAY_METHODS{$SplitGatewayMethod}->{'LogoName'}
             )
        );
    }

    $PaymentMethod->getSite()->child('PaymentMethods')->renumberChildren;
    $Servlet->vars('NewPaymentMethods',\@newPaymentMethods);

    $Form->executeFormError();

    return ;
}

sub _check_newOgoneMethods{
    my ( $Servlet,$PaymentMethod,$aSelectedSplitGatewayMethods,$hSplitGatewyMethods ) = @_;

    my $Shop = $PaymentMethod->getSite();
    my $Folder = $Shop->folder('PaymentMethods');
    my $Form = $Servlet->form;
    my $ExecuteError = 0;

    if (scalar @$aSelectedSplitGatewayMethods) {
        foreach my $SplitGatewayMethod (@$aSelectedSplitGatewayMethods) {

            if ($Folder->existsChild($hSplitGatewyMethods->{$SplitGatewayMethod}->{'Name'})) {
                $Servlet->vars('aOgoneMethod_'.$SplitGatewayMethod,1);
                $ExecuteError = 1;
                $Form->addFormError({
                    'Form'  => 'PaymentMethodOgone',
                    'Reason'=> 'OBJECT_EXISTS',
                    'Name'  => 'NewOgoneMethod'.$SplitGatewayMethod
                });
            }
        }
    } else {
        $Form->addFormError({
            'Form'  => 'PaymentMethodOgone',
            'Reason'=> 'NOTHING_SELECTED',
            'Name'  => 'NOTHING_SELECTED'
        });
    }

    my $LeftPaymentMethods = $Shop->featureCurrentValue('PaymentMethods') + scalar(@$aSelectedSplitGatewayMethods) - $Shop->featureMaxValue('PaymentMethods');
    if ( $LeftPaymentMethods >= scalar(@$aSelectedSplitGatewayMethods) ){
        $ExecuteError = 1;
        $Form->addFormError({
                'Form'  => 'PaymentMethodOgone',
                'Reason'=> 'FEATURE_LIMIT_EXCEEDED',
                'Name'  => 'FEATURE_LIMIT_EXCEEDED'
            });
    }
    if ( $ExecuteError == 1 ){
        $Form->executeFormError();
    }

    return $LeftPaymentMethods;
}

#==============================================================================
sub _newOgoneMethod {
    my ( $Servlet, $PaymentMethod, $SplitGatewayMethod, $MethodName, $LogoName ) = @_;

    my $Shop = $PaymentMethod->getSite();
    my $MethodAlias = $PaymentMethod->get('PaymentType')->get('Alias'); # it only can be Ogone or Postfinance
    my $PaymentType = LoadObjectByPath(JoinObjectPath(['PaymentTypes', $MethodAlias]));

    return unless defined $SplitGatewayMethod && $SplitGatewayMethod =~ /\S/;

    my $aLogos = GetShopPaymentLogos($Shop, LoadObjectByPath(JoinObjectPath(['PaymentTypes', $MethodAlias])));
    #my $SplitGatewayMethodAlias;
    my $PaymentTypeLogoID;
    foreach my $hLogo (@$aLogos) {
        if ($LogoName eq $hLogo->{'PaymentLogo'}->alias) {
            $PaymentTypeLogoID = $hLogo->{'PaymentTypeLogo'}->id;
        }
    }

    eval {
        Transaction( sub {
            $PaymentMethod = $PaymentType->newPaymentMethod($Shop, {
                'MerchantNameTest' => $PaymentMethod->get('MerchantNameTest'),
                'MerchantPasswordTest' => $PaymentMethod->get('MerchantPasswordTest'),
                'PassphraseTest' => $PaymentMethod->get('PassphraseTest'),
                'MerchantName' => $PaymentMethod->get('MerchantName'),
                'MerchantPassword' => $PaymentMethod->get('MerchantPassword'),
                'Passphrase' => $PaymentMethod->get('Passphrase'),
                'SplitGatewayMethod' => $SplitGatewayMethod,
                'Alias' => $MethodName,
                'Position' => 9999,
                'Shop' => $Shop,
            });

            # activate on all shipping methods
            InsertShippingPaymentMap({
                'ShippingMethodID'  => $_->id,
                'PaymentMethodID'   => $PaymentMethod->id
            }) foreach @{$Shop->get('ShippingMethods')};

            #insert new Logos
            if ($PaymentTypeLogoID){
                InsertShopPaymentLogo({
                    'ShopID'            => $Shop->id,
                    'PaymentTypeLogoID' => $PaymentTypeLogoID,
                }) unless ExistsShopPaymentLogo({
                    'ShopID'            => $Shop->id,
                    'PaymentTypeLogoID' => $PaymentTypeLogoID,
                });
            }
        });
    };
    if (ExistsError()) {
        my $Error = GetError();
        if ($Error->code eq 'FeatureLimitExceededGeneral') {
            $Servlet->vars('FeatureMaxValueReachedGeneral',1);
        }
        elsif ($Error->code  eq 'FeatureLimitExceeded'){
            $Servlet->vars('FeatureMaxValueReached', $Error->vars);
        }
        else {
            Error($Error);
        }
    }


    return $PaymentMethod;
}

1;
