#========================================================================================
# package      DE_EPAGES::Product::Hooks::ShopLanguage
# state        public
# description  adds needed data to products on change of the shop language
#========================================================================================
package DE_EPAGES::Product::Hooks::ShopLanguage;

use strict;
use DE_EPAGES::Shop::API::ShopLanguage qw ( SetNameForNewLanguage );

#========================================================================================
# function     OnInsertShopLanguage
#----------------------------------------------------------------------------------------
# syntax       OnInsertShopLanguage( $hParams );
#----------------------------------------------------------------------------------------
# description  write the existing name to all products, product types and attributes
#               in the new language (Hook OBJ_InsertShopLanguage)
#----------------------------------------------------------------------------------------
# input        $hParams | hook params, keys:
#               <ul>
#                 <li>Object         - ShopLanguage         - object
#                 <li>ShopLanguageID - object id            - int
#               </ul>
#========================================================================================
sub OnInsertShopLanguage {
    my ($hParams) = @_;

    my $ShopLanguage = $hParams->{'Object'};
    my $Shop = $ShopLanguage->getSite();

    if ($Shop->get('IsUnityRegistered')) {
        my $NewLanguageID = $ShopLanguage->get('LanguageID');
        my $DefaultLanguageID = $Shop->get('LanguageID');

        # set name for products
        my $aProducts = $Shop->get('Products');

        foreach my $Product (@$aProducts) {
            SetNameForNewLanguage($Product, $DefaultLanguageID, $NewLanguageID);
            if ($Product->countSubProducts > 0) {
                foreach my $SubProduct (@{$Product->subProducts}) {
                    SetNameForNewLanguage($SubProduct, $DefaultLanguageID, $NewLanguageID);
                }
            }
        }

        # set name for product types and attributes
        my @ProductTypes = @{$Shop->get('ProductTypes')->children};
        # add standard product type, too
        push @ProductTypes, $Shop->get('ProductClass');

        foreach my $ProductType (@ProductTypes) {
            SetNameForNewLanguage($ProductType, $DefaultLanguageID, $NewLanguageID);
            if ($ProductType->existsChild('Attributes')) {
                my $aProductAttributes = $ProductType->child('Attributes')->children;
                foreach my $ProductAttribute (@$aProductAttributes) {
                    SetNameForNewLanguage($ProductAttribute, $DefaultLanguageID, $NewLanguageID);
                    # preset values for attributes of type predef localized string
                    if ($ProductAttribute->get('Type') eq 'PreDefLocalizedString') {
                        foreach my $PreDefAttribute (@{$ProductAttribute->get('PreDefAttributes')}) {
                            unless (defined $PreDefAttribute->get('ValueLocString', $NewLanguageID)) {
                                my $ValueLocString = $PreDefAttribute->get('ValueLocString', $DefaultLanguageID);
                                $PreDefAttribute->set({'ValueLocString' => $ValueLocString}, $NewLanguageID)
                                    if defined $ValueLocString;
                            }
                        }
                    }
                }
            }
        }
    }

    return;
}

1;
