#========================================================================================
# package      DE_EPAGES::SIA::UI::PaymentMethodSIA
# base         DE_EPAGES::Payment::UI::PaymentMethod
# state        private
#----------------------------------------------------------------------------------------
# description  UI Controller for payment method
#========================================================================================
package DE_EPAGES::SIA::UI::PaymentMethodSIA;
use base DE_EPAGES::Payment::UI::PaymentMethod;

use DE_EPAGES::SIA::API::Types::MerchantRegistrationData;

use strict;

sub ViewRegistration {
    my $self = shift;
    my ($Servlet) = @_;

    return;
}

#========================================================================================
# function     ViewSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       ViewSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to view settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub ViewSettings {
    my $self = shift;
    my ($Servlet) = @_;

    return;
}

#========================================================================================
# function     SaveSettings
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveSettings( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save settings on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveSettings {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object();
    my $Form = $Servlet->form;

    # some form checks here
    if ( $PaymentMethod->hasPendingCurrentTransaction() ) {
        $Form->addFormError({
            'Reason' => 'SaveWhileTransactionIsPending',
            'Name'   => 'SaveWhileTransactionIsPending',
            'Form'   => 'SIASettings',
        });
        $Form->executeFormError();
    }
    else {
        $Form->form($PaymentMethod, 'SIASettings');
        $self->SaveRegistrationTransaction($Servlet);
        $self->Save($Servlet);
    }

    return;
}

#========================================================================================
# function     SaveOperationalMode
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveOperationalMode( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save the operational mode on the MBO settings page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveOperationalMode {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethod = $Servlet->object();
    my $Form = $Servlet->form;

    $Form->form($PaymentMethod, 'SIATestMode');
    $self->Save($Servlet);

    return;
}
#========================================================================================
# function     SaveRegistrationTransaction
# state        public
#----------------------------------------------------------------------------------------
# syntax       SaveRegistrationTransaction( $Servlet );
#----------------------------------------------------------------------------------------
# description  UI Controller to save registration transaction on the MBO register page.
#----------------------------------------------------------------------------------------
# input        $Servlet | Servlet | DE_EPAGES::Presentation::Servlet::BasePermission
#========================================================================================
sub SaveRegistrationTransaction {
    my $self = shift;
    my ($Servlet) = @_;

    my $PaymentMethodSia = $Servlet->object;
    my $Form             = $Servlet->form();

    my $ThreeDSecure = $Form->value('ThreeDS') ? 1 : 0;

    my $hRegistrationTransaction = $PaymentMethodSia->provideRegistrationTransactionData(
        $Form->value('PaymentNetwork'),
        $Form->value('MerchantID'),
        $Form->value('TerminalNumber'),
        $Form->value('MerchantTaxID'),
        $ThreeDSecure
    );

    $PaymentMethodSia->saveRegistrationTransaction($hRegistrationTransaction);

    return;
}

1;
